pub enum HostAlias {
Ip(IpAddr),
SourceIpFor(UrlPwa),
}Expand description
A value that can be resolved to an IpAddr.
Variants
Ip(IpAddr)
Literally, this IpAddr.
SourceIpFor(UrlPwa)
The default source IP address when contacting the by UrlPwa specified host.
The scheme must be either tcp or udp, and a port must be specified.
The url cannot have a username, password, path, query or fragment.
Implementations