pub enum UrlPwa {
PerhapsWithAlias(Url),
WithoutAlias(Url),
}Expand description
A Url that perhaps has as host name one of the aliases defined in super::Config::host_aliases.
Variants
PerhapsWithAlias(Url)
The host name of the Url might contain an alias.
WithoutAlias(Url)
Any alias has been replaced.
Implementations